@@ -482,10 +482,10 @@ extern "C" {
 # define ZPC_ERROR_PVSECRET_TYPE_NOT_SUPPORTED         79
 
 /**
- * \def ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV
- * \brief the given pvsecret ID does not belong to a secret on this system.
+ * \def ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV_OR_INVALID_TYPE
+ * \brief the given pvsecret ID does either not exist or belongs to a different secret type.
  */
-# define ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV         80
+# define ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV_OR_INVALID_TYPE         80
 
 /**
  * \def ZPC_ERROR_IOCTLVERIFYKEY2
@@ -493,6 +493,36 @@ extern "C" {
  */
 # define ZPC_ERROR_IOCTLVERIFYKEY2                     81
 
+/**
+ * \def ZPC_ERROR_HMAC_HASH_FUNCTION_NOTSET
+ * \brief HMAC hash function not set.
+ */
+# define ZPC_ERROR_HMAC_HASH_FUNCTION_NOTSET           82
+
+/**
+ * \def ZPC_ERROR_HMAC_HASH_FUNCTION_INVALID
+ * \brief HMAC hash function invalid.
+ */
+# define ZPC_ERROR_HMAC_HASH_FUNCTION_INVALID          83
+
+/**
+ * \def ZPC_ERROR_HMAC_KEYGEN_VIA_SYSFS_FAILED
+ * \brief HMAC key generation via sysfs attributes failed.
+ */
+# define ZPC_ERROR_HMAC_KEYGEN_VIA_SYSFS               84
+
+/**
+ * \def ZPC_ERROR_CREATE_BLOCKSIZED_KEY
+ * \brief Creating a block-sized HMAC key failed.
+ */
+# define ZPC_ERROR_CREATE_BLOCKSIZED_KEY               85
+
+/**
+ * \def ZPC_ERROR_XTS_KEYGEN_VIA_SYSFS
+ * \brief creating a full-xts key via sysfs attributes failed.
+ */
+# define ZPC_ERROR_XTS_KEYGEN_VIA_SYSFS                86
+
 /**
  * \fn const char *zpc_error_string(int err)
  * \brief Map an error code to the corresponding error string.
