@@ -107,8 +107,7 @@ zpc_aes_cbc_set_key(struct zpc_aes_cbc *aes_cbc, struct zpc_aes_key *aes_key)
 		goto ret;
 
 	if (aes_cbc->aes_key == aes_key) {
-		DEBUG("aes-cbc context at %p: key at %p already set", aes_cbc,
-		    aes_key);
+		DEBUG("aes-cbc context at %p: key at %p already set", aes_cbc, aes_key);
 		rc = 0; /* nothing to do */
 		goto ret;
 	}
@@ -128,11 +127,9 @@ zpc_aes_cbc_set_key(struct zpc_aes_cbc *aes_cbc, struct zpc_aes_key *aes_key)
 
 	DEBUG("aes-cbc context at %p: key at %p set", aes_cbc, aes_key);
 
-	memcpy(aes_cbc->param.protkey, aes_key->prot.protkey,
-	    sizeof(aes_cbc->param.protkey));
+	memcpy(aes_cbc->param.protkey, aes_key->prot.protkey, sizeof(aes_cbc->param.protkey));
 
-	aes_cbc->fc =
-	    CPACF_KMC_ENCRYPTED_AES_128 + (aes_key->keysize - 128) / 64;
+	aes_cbc->fc = CPACF_KMC_ENCRYPTED_AES_128 + (aes_key->keysize - 128) / 64;
 
 	aes_cbc->aes_key = aes_key;
 	aes_cbc->key_set = 1;
@@ -298,6 +295,7 @@ zpc_aes_cbc_encrypt(struct zpc_aes_cbc *aes_cbc, u8 * c, const u8 * m,
 	}
 	if (mlen % 16 != 0) {
 		rc = ZPC_ERROR_MLEN;
+		goto ret;
 	}
 
 	if (!aes_cbc->key_set) {
@@ -326,21 +324,16 @@ zpc_aes_cbc_encrypt(struct zpc_aes_cbc *aes_cbc, u8 * c, const u8 * m,
 					goto ret;
 				}
 				if (rc == ZPC_ERROR_WKVPMISMATCH) {
-					rv = pthread_mutex_lock(&aes_cbc->
-					    aes_key->lock);
+					rv = pthread_mutex_lock(&aes_cbc->aes_key->lock);
 					assert(rv == 0);
 
 					DEBUG
 					    ("aes-cbc context at %p: re-derive protected key from %s secure key from aes key at %p",
-					    aes_cbc, i == 0 ? "current" : "old",
-					    aes_cbc->aes_key);
-					rc = aes_key_sec2prot(aes_cbc->aes_key,
-					    i);
-					memcpy(param->protkey, protkey->protkey,
-					    sizeof(param->protkey));
+					    aes_cbc, i == 0 ? "current" : "old", aes_cbc->aes_key);
+					rc = aes_key_sec2prot(aes_cbc->aes_key, i);
+					memcpy(param->protkey, protkey->protkey, sizeof(param->protkey));
 
-					rv = pthread_mutex_unlock(&aes_cbc->
-					    aes_key->lock);
+					rv = pthread_mutex_unlock(&aes_cbc->aes_key->lock);
 					assert(rv == 0);
 				}
 				if (rc)
@@ -417,21 +410,16 @@ zpc_aes_cbc_decrypt(struct zpc_aes_cbc *aes_cbc, u8 * m, const u8 * c,
 					goto ret;
 				}
 				if (rc == ZPC_ERROR_WKVPMISMATCH) {
-					rv = pthread_mutex_lock(&aes_cbc->
-					    aes_key->lock);
+					rv = pthread_mutex_lock(&aes_cbc->aes_key->lock);
 					assert(rv == 0);
 
 					DEBUG
 					    ("aes-cbc context at %p: re-derive protected key from %s secure key from aes key at %p",
-					    aes_cbc, i == 0 ? "current" : "old",
-					    aes_cbc->aes_key);
-					rc = aes_key_sec2prot(aes_cbc->aes_key,
-					    i);
-					memcpy(param->protkey, protkey->protkey,
-					    sizeof(param->protkey));
+					    aes_cbc, i == 0 ? "current" : "old", aes_cbc->aes_key);
+					rc = aes_key_sec2prot(aes_cbc->aes_key, i);
+					memcpy(param->protkey, protkey->protkey, sizeof(param->protkey));
 
-					rv = pthread_mutex_unlock(&aes_cbc->
-					    aes_key->lock);
+					rv = pthread_mutex_unlock(&aes_cbc->aes_key->lock);
 					assert(rv == 0);
 				}
 				if (rc)
