@@ -188,8 +188,14 @@ int zpc_ec_key_set_type(struct zpc_ec_key *ec_key, int type)
 	}
 
 	switch (type) {
-	case ZPC_EC_KEY_TYPE_CCA:        /* fall-through */
-	case ZPC_EC_KEY_TYPE_EP11:
+	case ZPC_EC_KEY_TYPE_CCA:
+		if (swcaps.uv_pvsecrets) {
+			/* CCA adapters are not usable in a secure execution env. */
+			rc = ZPC_ERROR_NOTSUP;
+			DEBUG("return %d (%s)", rc, zpc_error_string(rc));
+		}
+		break;
+	case ZPC_EC_KEY_TYPE_EP11:        /* fall-through */
 	case ZPC_EC_KEY_TYPE_PVSECRET:
 		break;
 	default:
@@ -678,7 +684,7 @@ int zpc_ec_key_import(struct zpc_ec_key *ec_key, const unsigned char *buf,
 
 	if (ec_key->type == ZPC_EC_KEY_TYPE_PVSECRET) {
 		if (ec_key_blob_is_valid_pvsecret_id(ec_key, buf) != 0) {
-			rc = ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV;
+			rc = ZPC_ERROR_PVSECRET_ID_NOT_FOUND_IN_UV_OR_INVALID_TYPE;
 			goto ret;
 		}
 	}
@@ -722,6 +728,7 @@ int zpc_ec_key_import(struct zpc_ec_key *ec_key, const unsigned char *buf,
 		ec_key->pubkey_set = 1;
 		rv = pthread_mutex_lock(&ep11lock);
 		assert(rv == 0);
+		rc = -EIO;
 		for (i = 0; i < ec_key->napqns; i++) {
 			rc = get_ep11_target_for_apqn(&ep11, ec_key->apqns[i].card,
 					ec_key->apqns[i].domain, &target, true);
@@ -823,14 +830,14 @@ int zpc_ec_key_import_clear(struct zpc_ec_key *ec_key, const unsigned char *pubk
 		rc = ZPC_ERROR_OBJINUSE;
 		goto ret;
 	}
-	if (ec_key->curve_set != 1) {
-		rc = ZPC_ERROR_EC_CURVE_NOTSET;
-		goto ret;
-	}
 	if (ec_key->type_set != 1) {
 		rc = ZPC_ERROR_KEYTYPENOTSET;
 		goto ret;
 	}
+	if (ec_key->curve_set != 1) {
+		rc = ZPC_ERROR_EC_CURVE_NOTSET;
+		goto ret;
+	}
 	if (ec_key->type != ZPC_EC_KEY_TYPE_PVSECRET && ec_key->apqns_set != 1) {
 		rc = ZPC_ERROR_APQNSNOTSET;
 		goto ret;
