@@ -106,7 +106,6 @@ static int get_cca_version(struct cca_lib *cca, bool verbose)
 	long return_code, reason_code;
 	long version_data_length;
 	long exit_data_len = 0;
-	char date[20];
 
 	util_assert(cca != NULL, "Internal error: cca is NULL");
 
@@ -137,8 +136,8 @@ static int get_cca_version(struct cca_lib *cca, bool verbose)
 	version_data[sizeof(version_data) - 1] = '\0';
 	pr_verbose(verbose, "CCA Version string: %s", version_data);
 
-	if (sscanf((char *)version_data, "%u.%u.%uz%s", &cca->version.ver,
-		   &cca->version.rel, &cca->version.mod, date) != 4) {
+	if (sscanf((char *)version_data, "%u.%u.%u", &cca->version.ver,
+		   &cca->version.rel, &cca->version.mod) != 3) {
 		DEBUG("CCA library version is invalid: %s", version_data);
 		return -EINVAL;
 	}
