@@ -8,7 +8,9 @@
 #include "testlib.h"
 
 #include "zpc/aes_key.h"
+#include "zpc/aes_xts_key.h"
 #include "zpc/ecc_key.h"
+#include "zpc/hmac.h"
 
 #include <assert.h>
 #include <limits.h>
@@ -27,6 +29,12 @@
 #define ENV_EC_KEY_TYPE		"ZPC_TEST_EC_KEY_TYPE"
 #define ENV_EC_KEY_FLAGS	"ZPC_TEST_EC_KEY_FLAGS"
 
+#define ENV_HMAC_KEY_TYPE	"ZPC_TEST_HMAC_KEY_TYPE"
+#define ENV_HMAC_HASH_FUNC	"ZPC_TEST_HMAC_HASH_FUNCTION"
+
+#define ENV_AES_XTS_KEY_TYPE       "ZPC_TEST_AES_XTS_KEY_TYPE"
+#define ENV_AES_XTS_KEY_SIZE       "ZPC_TEST_AES_XTS_KEY_SIZE"
+
 /*
  * This file must be created by the tester before running tests with key
  * type ZPC_AES_KEY_TYPE_PVSECRET or ZPC_EC_KEY_TYPE_PVSECRET.
@@ -300,8 +308,10 @@ testlib_env_aes_key_apqns(const char *apqns[257])
 	int i;
 
 	env = getenv(ENV_AES_KEY_APQNS);
-	if (env == NULL)
+	if (env == NULL) {
+		apqns[0] = NULL;
 		return -1;
+	}
 
 	i = 0;
 	tok = strtok(env, " \t\n,");
@@ -322,8 +332,10 @@ testlib_env_ec_key_apqns(const char *apqns[257])
 	int i;
 
 	env = getenv(ENV_EC_KEY_APQNS);
-	if (env == NULL)
+	if (env == NULL) {
+		apqns[0] = NULL;
 		return -1;
+	}
 
 	i = 0;
 	tok = strtok(env, " \t\n,");
@@ -379,6 +391,44 @@ ret:
 	return type;
 }
 
+int
+testlib_env_aes_xts_key_type(void)
+{
+	int type = -1;	/* Invalid key-type. */
+	char *env = NULL;
+
+	env = getenv(ENV_AES_XTS_KEY_TYPE);
+	if (env == NULL)
+		goto ret;
+
+	if (strcmp(env, "ZPC_AES_XTS_KEY_TYPE_PVSECRET") == 0)
+		type = ZPC_AES_XTS_KEY_TYPE_PVSECRET;
+
+ret:
+	return type;
+}
+
+int
+testlib_env_aes_xts_key_size(void)
+{
+	int size = -1;	/* Invalid key-size. */
+	long sizelong = LONG_MIN;
+	char *env = NULL, *endptr = NULL;
+
+	env = getenv(ENV_AES_XTS_KEY_SIZE);
+	if (env == NULL || env[0] == '\0')
+		goto ret;
+
+	sizelong = strtol(env, &endptr, 0);
+	if (*endptr != '\0' || sizelong < INT_MIN || sizelong > INT_MAX)
+		goto ret;
+
+	size = (int)sizelong;
+ret:
+	return size;
+}
+
+
 int
 testlib_env_ec_key_type(void)
 {
@@ -470,6 +520,49 @@ ret:
 	return curve;
 }
 
+int
+testlib_env_hmac_key_type(void)
+{
+	int type = -1;	/* Invalid key-type. */
+	char *env = NULL;
+
+	env = getenv(ENV_HMAC_KEY_TYPE);
+	if (env == NULL) {
+		type = -2;
+		goto ret;
+	}
+
+	if (strcmp(env, "ZPC_HMAC_KEY_TYPE_PVSECRET") == 0)
+		type = ZPC_HMAC_KEY_TYPE_PVSECRET;
+
+ret:
+	return type;
+}
+
+zpc_hmac_hashfunc_t testlib_env_hmac_hashfunc(void)
+{
+	zpc_hmac_hashfunc_t hfunc = ZPC_HMAC_HASHFUNC_INVALID;
+	char *env = NULL;
+
+	env = getenv(ENV_HMAC_HASH_FUNC);
+	if (env == NULL) {
+		hfunc = ZPC_HMAC_HASHFUNC_NOT_SET;
+		goto ret;
+	}
+
+	if (strcmp(env, "SHA-224") == 0)
+		hfunc = ZPC_HMAC_HASHFUNC_SHA_224;
+	else if (strcmp(env, "SHA-256") == 0)
+		hfunc = ZPC_HMAC_HASHFUNC_SHA_256;
+	else if (strcmp(env, "SHA-384") == 0)
+		hfunc = ZPC_HMAC_HASHFUNC_SHA_384;
+	else if (strcmp(env, "SHA-512") == 0)
+		hfunc = ZPC_HMAC_HASHFUNC_SHA_512;
+
+ret:
+	return hfunc;
+}
+
 char * testlib_env_pvsecret_list_file(void)
 {
 	return getenv(ENV_PVSECRET_LIST_FILE);
@@ -648,7 +741,7 @@ typedef enum {
 	EXTRACT_SECRETKEY,
 } testkey_extract_mode_t;
 
-const char *type2string(int type)
+static const char *type2string(int type)
 {
 	switch (type) {
 	case ZPC_AES_KEY_TYPE_CCA_DATA:
@@ -670,7 +763,7 @@ const char *type2string(int type)
  * whenever the pvsecret utility would use different strings, this must be
  * adapted here.
  */
-int pvsec_found(const char *buffer, int pvsectype)
+static int pvsec_found(const char *buffer, int pvsectype)
 {
 	switch (pvsectype) {
 	case ZPC_AES_SECRET_AES_128:
@@ -685,6 +778,14 @@ int pvsec_found(const char *buffer, int pvsectype)
 		if (strstr(buffer, "AES-256-KEY") != NULL)
 			return 1;
 		break;
+	case ZPC_XTS_SECRET_AES_XTS_128:
+		if (strstr(buffer, "AES-XTS-128-KEY") != NULL)
+			return 1;
+		break;
+	case ZPC_XTS_SECRET_AES_XTS_256:
+		if (strstr(buffer, "AES-XTS-256-KEY") != NULL)
+			return 1;
+		break;
 	case ZPC_EC_SECRET_ECDSA_P256:
 		if (strstr(buffer, "EC-SECP256R1-PRIVATE-KEY") != NULL)
 			return 1;
@@ -705,6 +806,14 @@ int pvsec_found(const char *buffer, int pvsectype)
 		if (strstr(buffer, "EC-ED448-PRIVATE-KEY") != NULL)
 			return 1;
 		break;
+	case ZPC_HMAC_SECRET_HMAC_SHA_256:
+		if (strstr(buffer, "HMAC-SHA-256-KEY") != NULL)
+			return 1;
+		break;
+	case ZPC_HMAC_SECRET_HMAC_SHA_512:
+		if (strstr(buffer, "HMAC-SHA-512-KEY") != NULL)
+			return 1;
+		break;
 	default:
 		break;
 	}
@@ -716,15 +825,20 @@ int pvsec_found(const char *buffer, int pvsectype)
  * Convert a given hex string of the form " 0xabcde ...." into a byte array.
  * Note that a leading space char is expected at the beginning of the string.
  */
-int extract_bytes(const char *buffer, unsigned char *outbuf, unsigned int *outlen)
+static int extract_bytes(const char *buffer, unsigned char *outbuf,
+		size_t *outlen)
 {
 	unsigned char *sec = NULL;
 	char *tmp;
-	size_t seclen;
+	size_t seclen = 0;
 	int rc = 1;
 
-	/* Remove leading ' 0x' and ending newline */
-	tmp = (char *)buffer + 3;
+	/* Skip possible leading blanks */
+	tmp = (char *)buffer;
+	while (strlen(tmp) > 1 && tmp[0] == ' ')
+		tmp += 1;
+
+	/* Remove ending newline */
 	tmp[strlen(tmp) - 1] = 0;
 
 	/* Convert hex string to byte array */
@@ -743,11 +857,6 @@ ret:
 }
 
 /*
- * Extract the pvsecret ID or secret key data from a text file created with
- * the 'pvsecret' utility. The name of the text file must be specified via
- * env variable ZPC_TEST_PVSECRET_LIST_FILE. If no pvsecret of this type is
- * contained in the file (and thus on this system), return an error.
- *
  * The pvsecrets-list file contains AES pvsecret IDs in this form:
  *
  * 2 AES-128-KEY:
@@ -770,37 +879,14 @@ ret:
  *         1 error opening list file
  *         2 no pvsecret found for given type
  */
-int testlib_get_aes_data(int size, unsigned char *outbuf,
-			unsigned int *outlen, testkey_extract_mode_t mode)
+static int get_key_bytes_from_list_file(unsigned char *outbuf, size_t *outlen,
+		int pvsectype, int lines_to_skip)
 {
-	FILE *fd;
-	const unsigned int BUF_LEN = 300;
+	const size_t BUF_LEN = 1024;
 	char buffer[BUF_LEN] = { 0, };
+	FILE *fd;
 	char *fn;
-	int i, pvsectype, rc, lines_to_skip;
-
-	switch (mode) {
-	case EXTRACT_ID:
-		lines_to_skip = 1;
-		break;
-	case EXTRACT_SECRETKEY:
-		lines_to_skip = 2;
-		break;
-	default:
-		return 3; /* should not occur */
-	}
-
-	switch (size) {
-	case 128:
-		pvsectype = ZPC_AES_SECRET_AES_128;
-		break;
-	case 192:
-		pvsectype = ZPC_AES_SECRET_AES_192;
-		break;
-	default: /* 256 */
-		pvsectype = ZPC_AES_SECRET_AES_256;
-		break;
-	}
+	int i, rc;
 
 	fn = testlib_env_pvsecret_list_file();
 	if (!fn)
@@ -832,14 +918,70 @@ ret:
 	return rc;
 }
 
+/*
+ * Extract the pvsecret ID or secret key data from a text file created with
+ * the 'pvsecret' utility. The name of the text file must be specified via
+ * env variable ZPC_TEST_PVSECRET_LIST_FILE. If no pvsecret of this type is
+ * contained in the file (and thus on this system), return an error.
+ *
+ * @return 0 success, outbuf contains extracted byte array
+ *         1 error opening list file
+ *         2 no pvsecret found for given type
+ */
+static int testlib_get_key_data(int size, unsigned char *outbuf,
+		size_t *outlen, testkey_extract_mode_t mode, int fxts)
+{
+	int pvsectype, rc, lines_to_skip;
+
+	switch (mode) {
+	case EXTRACT_ID:
+		lines_to_skip = 1;
+		break;
+	case EXTRACT_SECRETKEY:
+		lines_to_skip = 2;
+		break;
+	default:
+		return 3; /* should not occur */
+	}
+
+	switch (size) {
+	case 128:
+		if (!fxts)
+			pvsectype = ZPC_AES_SECRET_AES_128;
+		else
+			pvsectype = ZPC_XTS_SECRET_AES_XTS_128;
+		break;
+	case 192:
+		pvsectype = ZPC_AES_SECRET_AES_192;
+		break;
+	case 256:
+		if (!fxts)
+			pvsectype = ZPC_AES_SECRET_AES_256;
+		else
+			pvsectype = ZPC_XTS_SECRET_AES_XTS_256;
+		break;
+	case 512:
+		pvsectype = ZPC_HMAC_SECRET_HMAC_SHA_256;
+		break;
+	case 1024:
+		pvsectype = ZPC_HMAC_SECRET_HMAC_SHA_512;
+		break;
+	default:
+		return 3; /* should not occur */
+	}
+
+	rc = get_key_bytes_from_list_file(outbuf, outlen, pvsectype, lines_to_skip);
+
+	return rc;
+}
+
 int testlib_set_aes_key_from_pvsecret(struct zpc_aes_key *aes_key, int keysize)
 {
 	unsigned char pvsec_id[32] = { 0, };
-	unsigned int id_len;
-	size_t i;
+	size_t id_len, i;
 	int rc;
 
-	rc = testlib_get_aes_data(keysize, pvsec_id, &id_len, EXTRACT_ID);
+	rc = testlib_get_key_data(keysize, pvsec_id, &id_len, EXTRACT_ID, 0);
 	switch (rc) {
 	case 0:
 		rc = zpc_aes_key_import(aes_key, pvsec_id, 32);
@@ -856,7 +998,7 @@ int testlib_set_aes_key_from_pvsecret(struct zpc_aes_key *aes_key, int keysize)
 			"ZPC_TEST_PVSECRET_LIST_FILE not set, or file does not exist.\n");
 		break;
 	case 2:
-		printf("[  WARNING ] No AES pvsecret with size %d available on this system.\n",
+		printf("[  WARNING ] No 'AES-%d-KEY' pvsecret available on this system.\n",
 			keysize);
 		break;
 	}
@@ -864,14 +1006,18 @@ int testlib_set_aes_key_from_pvsecret(struct zpc_aes_key *aes_key, int keysize)
 	return rc;
 }
 
-int testlib_set_aes_key_from_file(struct zpc_aes_key *aes_key, int type, int size)
+int testlib_set_aes_key_from_file(struct zpc_aes_key *aes_key, int type, int size,
+		int fxts, int key_num)
 {
 	unsigned char pvsec_id[32] = { 0, };
 	unsigned char keybytes[256] = { 0, };
-	unsigned int idlen, byteslen;
+	size_t idlen, byteslen;
 	int rc;
+	unsigned char *tmp;
 
-	rc = testlib_get_aes_data(size, pvsec_id, &idlen, EXTRACT_ID);
+	assert(key_num == 1 || key_num == 2);
+
+	rc = testlib_get_key_data(size, pvsec_id, &idlen, EXTRACT_ID, fxts);
 	switch (rc) {
 	case 0:
 		break;
@@ -880,19 +1026,30 @@ int testlib_set_aes_key_from_file(struct zpc_aes_key *aes_key, int type, int siz
 			"ZPC_TEST_PVSECRET_LIST_FILE not set, or file does not exist.\n");
 		goto ret;
 	case 2:
-		printf("[  WARNING ] No AES pvsecret with size %d available on this system.\n",
+		printf("[  WARNING ] No 'AES-%d-KEY' pvsecret available on this system.\n",
 				size);
 		goto ret;
 	}
 
-	rc = testlib_get_aes_data(size, keybytes, &byteslen, EXTRACT_SECRETKEY);
+	rc = testlib_get_key_data(size, keybytes, &byteslen, EXTRACT_SECRETKEY, fxts);
 	if (rc != 0) {
 		printf("[     INFO ] Cannot obtain clear key bytes for 'AES-%d-KEY' from list file.\n",
 			size);
 		goto ret;
 	}
 
-	rc = zpc_aes_key_import_clear(aes_key, keybytes);
+	if ((!fxts && byteslen != (size_t)size / 8) ||
+		(fxts && byteslen != (size_t)size * 2 / 8)) {
+		printf("[  WARNING ] Clear key bytes in list file for 'AES-%s%d-KEY' have an invalid length of %ld bytes.\n",
+			fxts ? "XTS-" : "", size, byteslen);
+		goto ret;
+	}
+
+	tmp = &keybytes[0];
+	if (fxts && key_num == 2)
+		tmp += byteslen / 2; /* take 2nd half for key2 */
+
+	rc = zpc_aes_key_import_clear(aes_key, tmp);
 	if (rc != 0) {
 		printf("[     INFO ] Cannot import clear key data for %s-type 'AES-%d-KEY' from list file, rc = %d.\n",
 			type2string(type), size, rc);
@@ -943,13 +1100,9 @@ ret:
  *         2 no pvsecret found for given type
  */
 int testlib_get_ec_data(zpc_ec_curve_t curve, unsigned char *outbuf,
-			unsigned int *outlen, testkey_extract_mode_t mode)
+		size_t *outlen, testkey_extract_mode_t mode)
 {
-	FILE *fd;
-	const unsigned int BUF_LEN = 300;
-	char buffer[BUF_LEN] = { 0, };
-	char *fn;
-	int i, pvsectype, rc, lines_to_skip;
+	int pvsectype, rc, lines_to_skip;
 
 	switch (mode) {
 	case EXTRACT_ID:
@@ -983,32 +1136,7 @@ int testlib_get_ec_data(zpc_ec_curve_t curve, unsigned char *outbuf,
 		break;
 	}
 
-	fn = testlib_env_pvsecret_list_file();
-	if (!fn)
-		return 1;
-
-	if ((fd = fopen(fn, "r")) == NULL)
-		return 1;
-
-	while (fgets(buffer, BUF_LEN, fd)) {
-		if (pvsec_found(buffer, pvsectype)) {
-			for (i = 0; i < lines_to_skip; i++) {
-				if (!fgets(buffer, BUF_LEN, fd)) { /* skip to next line */
-					rc = 2;
-					goto ret;
-				}
-			}
-			if (extract_bytes(buffer, outbuf, outlen) == 0) {
-				rc = 0;
-				goto ret;
-			}
-		}
-	}
-
-	rc = 2;
-
-ret:
-	fclose(fd);
+	rc = get_key_bytes_from_list_file(outbuf, outlen, pvsectype, lines_to_skip);
 
 	return rc;
 }
@@ -1028,58 +1156,12 @@ ret:
  *         1 error opening list file
  *         2 no pubkey found for given pvsecret ID
  */
-int testlib_add_ec_public_key(const char *pvsec_id, unsigned char *pubkey,
-			unsigned int *publen)
-{
-	FILE *fd;
-	const unsigned int BUF_LEN = 300;
-	char buffer[BUF_LEN] = { 0, };
-	char *fn;
-	int rc;
-	unsigned char *bytes;
-	size_t bytelen;
-	char *tmp;
-
-	fn = testlib_env_pvsecret_list_file();
-	if (!fn)
-		return 1;
-
-	if ((fd = fopen(fn, "r")) == NULL)
-		return 1;
-
-	while (fgets(buffer, BUF_LEN, fd)) {
-		if (strstr(buffer, "0x") != NULL) {
-			/* Remove leading ' 0x' and ending newline */
-			tmp = (char *)buffer + 3;
-			tmp[strlen(tmp) - 1] = 0;
-			bytes = testlib_hexstr2buf(tmp, &bytelen);
-			if (bytes != NULL && bytelen > 0 && memcmp(bytes, pvsec_id, bytelen) == 0) {
-				if (fgets(buffer, BUF_LEN, fd)) { /* skip to next line */
-					if (strstr(buffer, "0x") != NULL) {
-						if (extract_bytes(buffer, pubkey, publen) == 0) {
-							rc = 0;
-							goto ret;
-						}
-					}
-				}
-			}
-		}
-	}
-
-	rc = 2;
-
-ret:
-	fclose(fd);
-
-	return rc;
-}
-
 int testlib_set_ec_key_from_pvsecret(struct zpc_ec_key *ec_key, int type,
-			zpc_ec_curve_t curve)
+		zpc_ec_curve_t curve)
 {
 	unsigned char pvsec_id[32] = { 0, };
 	unsigned char pubkey[256] = { 0, };
-	unsigned int i, id_len, publen;
+	size_t i, id_len, publen;
 	int rc;
 
 	rc = testlib_get_ec_data(curve, pvsec_id, &id_len, EXTRACT_ID);
@@ -1093,7 +1175,7 @@ int testlib_set_ec_key_from_pvsecret(struct zpc_ec_key *ec_key, int type,
 			for (i = 0; i < sizeof(pvsec_id); i++)
 				printf("%02X%c",pvsec_id[i],((i+1)%16)?' ':'\n');
 		} else {
-			rc = testlib_add_ec_public_key((const char *)pvsec_id, pubkey, &publen);
+			rc = testlib_get_ec_data(curve, pubkey, &publen, EXTRACT_PUBKEY);
 			if (rc == 0) {
 				rc = zpc_ec_key_import_clear(ec_key, pubkey, publen, NULL, 0);
 				if (rc == 0) {
@@ -1127,7 +1209,9 @@ int testlib_set_ec_key_from_file(struct zpc_ec_key *ec_key, int type, zpc_ec_cur
 	unsigned char pvsec_id[32] = { 0, };
 	unsigned char privkey[256] = { 0, };
 	unsigned char pubkey[256] = { 0, };
-	unsigned int idlen, privlen, publen;
+	const unsigned int curve2privlen[] = { 32, 48, 66, 32, 57 };
+	const unsigned int curve2publen[] = { 64, 96, 132 , 32, 57};
+	size_t idlen, privlen, publen;
 	int rc;
 
 	rc = testlib_get_ec_data(curve, pvsec_id, &idlen, EXTRACT_ID);
@@ -1151,6 +1235,15 @@ int testlib_set_ec_key_from_file(struct zpc_ec_key *ec_key, int type, zpc_ec_cur
 		goto ret;
 	}
 
+	if (publen != curve2publen[curve]) {
+		printf("[  WARNING ] Clear public key bytes in list file for 'EC-%s-PRIVATE-KEY' have an invalid length of %ld bytes.\n",
+			curve2string[curve], publen);
+		if (publen == curve2privlen[curve]) {
+			printf("[     INFO ] Most likely the order is wrong: the public key comes first.\n");
+		}
+		goto ret;
+	}
+
 	rc = testlib_get_ec_data(curve, privkey, &privlen, EXTRACT_PRIVKEY);
 	if (rc != 0) {
 		printf("[     INFO ] Cannot obtain clear private key bytes for 'EC-%s-PRIVATE-KEY' from list file.\n",
@@ -1172,3 +1265,108 @@ int testlib_set_ec_key_from_file(struct zpc_ec_key *ec_key, int type, zpc_ec_cur
 ret:
 	return rc;
 }
+
+int testlib_set_hmac_key_from_pvsecret(struct zpc_hmac_key *hmac_key, size_t keysize)
+{
+	unsigned char pvsec_id[32] = { 0, };
+	size_t i, id_len;
+	int rc;
+
+	rc = testlib_get_key_data(keysize, pvsec_id, &id_len, EXTRACT_ID, 0);
+	switch (rc) {
+	case 0:
+		rc = zpc_hmac_key_import(hmac_key, pvsec_id, 32);
+		if (rc != 0) {
+			printf("[    ERROR ] zpc_hmac_key_import from 'HMAC-SHA-%d-KEY' pvsecret failed with rc = %d.\n",
+				keysize == 512 ? 256 : 512, rc);
+			printf("Tried with ID:\n");
+			for (i = 0; i < sizeof(pvsec_id); i++)
+				printf("%02X%c",pvsec_id[i],((i+1)%16)?' ':'\n');
+		}
+		break;
+	case 1:
+		printf("[  WARNING ] Could not open pvsecret list file. Probably "
+			"ZPC_TEST_PVSECRET_LIST_FILE not set, or file does not exist.\n");
+		break;
+	case 2:
+		printf("[  WARNING ] No 'HMAC-SHA-%d-KEY' pvsecret available on this system.\n",
+			keysize == 512 ? 256 : 512);
+		break;
+	}
+
+	return rc;
+}
+
+int testlib_set_hmac_key_from_file(struct zpc_hmac_key *hmac_key, int type, size_t keysize)
+{
+	unsigned char pvsec_id[32] = { 0, };
+	unsigned char keybytes[256] = { 0, };
+	size_t idlen, byteslen;
+	int rc;
+
+	rc = testlib_get_key_data(keysize, pvsec_id, &idlen, EXTRACT_ID, 0);
+	switch (rc) {
+	case 0:
+		break;
+	case 1:
+		printf("[  WARNING ] Could not open pvsecret list file. Probably "
+			"ZPC_TEST_PVSECRET_LIST_FILE not set, or file does not exist.\n");
+		goto ret;
+	case 2:
+		printf("[  WARNING ] No 'HMAC-SHA-%d-KEY' pvsecret available on this system.\n",
+			keysize == 512 ? 256 : 512);
+		goto ret;
+	}
+
+	rc = testlib_get_key_data(keysize, keybytes, &byteslen, EXTRACT_SECRETKEY, 0);
+	if (rc != 0) {
+		printf("[     INFO ] Cannot obtain clear key bytes for 'HMAC-SHA-%d-KEY' from list file.\n",
+			keysize == 512 ? 256 : 512);
+		goto ret;
+	}
+
+	rc = zpc_hmac_key_import_clear(hmac_key, keybytes, byteslen);
+	if (rc != 0) {
+		printf("[     INFO ] Cannot import clear key data for %s-type 'HMAC-SHA-%d-KEY' from list file, rc = %d.\n",
+			type2string(type), keysize == 512 ? 256 : 512, rc);
+		goto ret;
+	}
+
+	rc = 0;
+	printf("[       OK ] Imported clear key data for %s-type 'HMAC-SHA-%d-KEY' from list file.\n",
+		type2string(type), keysize == 512 ? 256 : 512);
+
+ret:
+	return rc;
+}
+
+int testlib_set_aes_xts_key_from_pvsecret(struct zpc_aes_xts_key *aes_key, int keysize)
+{
+	unsigned char pvsec_id[32] = { 0, };
+	size_t id_len, i;
+	int rc;
+
+	rc = testlib_get_key_data(keysize, pvsec_id, &id_len, EXTRACT_ID, 1);
+	switch (rc) {
+	case 0:
+		rc = zpc_aes_xts_key_import(aes_key, pvsec_id, 32);
+		if (rc != 0) {
+			printf("[    ERROR ] zpc_aes_key_import from 'AES-XTS-%d-KEY' pvsecret failed with rc = %d.\n",
+					keysize, rc);
+			printf("Tried with ID:\n");
+			for (i = 0; i < sizeof(pvsec_id); i++)
+				printf("%02X%c",pvsec_id[i],((i+1)%16)?' ':'\n');
+		}
+		break;
+	case 1:
+		printf("[  WARNING ] Could not open pvsecret list file. Probably "
+			"ZPC_TEST_PVSECRET_LIST_FILE not set, or file does not exist.\n");
+		break;
+	case 2:
+		printf("[  WARNING ] No 'AES-XTS-%d-KEY' pvsecret available on this system.\n",
+			keysize);
+		break;
+	}
+
+	return rc;
+}
